// index.js

import {
  select,
  csv,
  scaleLinear,
  scaleBand,
  axisLeft,
  axisBottom,
  format,
  area,
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = (data) => {
  // Select the initial 10 store areas
  const initialData = data.slice(0, 10);

  // Define x and y scales
  const xScale = scaleBand()
    .domain(initialData.map((d) => d.Store_Area))
    .range([0, width])
    .padding(0.1);

  const yScale = scaleLinear()
    .domain([
      0,
      Math.max(...initialData.map((d) => d.Store_Sales)),
    ])
    .range([height, 0]);

  // Add x-axis
  svg
    .append('g')
    .attr('transform', `translate(0,${height})`)
    .call(axisBottom(xScale))
    .append('text')
    .attr('x', width / 2)
    .attr('y', 40)
    .attr('fill', 'black')
    .text('Store Area');

  // Add y-axis
  svg
    .append('g')
    .call(axisLeft(yScale))
    .append('text')
    .attr('transform', 'rotate(-90)')
    .attr('x', -height / 2)
    .attr('y', -40)
    .attr('fill', 'black')
    .text('Store Sales');

  // Define the area generator
  const areaGenerator = area()
    .x((d) => xScale(d.Store_Area) + xScale.bandwidth() / 2)
    .y0(height)
    .y1((d) => yScale(d.Store_Sales));

  // Draw the area
  svg
    .append('path')
    .datum(initialData)
    .attr('fill', 'lightblue')
    .attr('d', areaGenerator);
};

csv(
  'https://gist.githubusercontent.com/rd0604/19b55be49e8e20ab9d9d500ccd40444e/raw/0486dc9fb584aa8378279da66507a8f4ccb54285/Stores.csv',
).then((data) => {
  // Parse the Store_Sales values as numbers
  data.forEach((d) => {
    d['Store_Sales'] = +d['Store_Sales'];
  });
  render(data);
});
